# RulesBasedClassification
Developing General Rules Based Classification (RBC) methodology for aiding detection of classes from different satellite sensors. 

![Example Deep Learning Heatmap](https://github.com/JRainbowOS/RulesBasedClassification/blob/master/images/TM0011_buildings_heatmap_sample.PNG)
